@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_sdb import SimpleDBClient
 
-    session = boto3.Session()
-
     client: SimpleDBClient = boto3.client("sdb")
-    session_client: SimpleDBClient = session.client("sdb")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
@@ -62,29 +59,29 @@ class Exceptions:
 
 class SimpleDBClient:
     """
-    [SimpleDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client)
+    [SimpleDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client)
     """
 
     exceptions: Exceptions
 
     def batch_delete_attributes(self, DomainName: str, Items: List[DeletableItemTypeDef]) -> None:
         """
-        [Client.batch_delete_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.batch_delete_attributes)
+        [Client.batch_delete_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.batch_delete_attributes)
         """
 
     def batch_put_attributes(self, DomainName: str, Items: List[ReplaceableItemTypeDef]) -> None:
         """
-        [Client.batch_put_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.batch_put_attributes)
+        [Client.batch_put_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.batch_put_attributes)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.can_paginate)
         """
 
     def create_domain(self, DomainName: str) -> None:
         """
-        [Client.create_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.create_domain)
+        [Client.create_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.create_domain)
         """
 
     def delete_attributes(
@@ -95,17 +92,17 @@ class SimpleDBClient:
         Expected: UpdateConditionTypeDef = None,
     ) -> None:
         """
-        [Client.delete_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.delete_attributes)
+        [Client.delete_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.delete_attributes)
         """
 
     def delete_domain(self, DomainName: str) -> None:
         """
-        [Client.delete_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.delete_domain)
+        [Client.delete_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.delete_domain)
         """
 
     def domain_metadata(self, DomainName: str) -> DomainMetadataResultTypeDef:
         """
-        [Client.domain_metadata documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.domain_metadata)
+        [Client.domain_metadata documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.domain_metadata)
         """
 
     def generate_presigned_url(
@@ -116,7 +113,7 @@ class SimpleDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.generate_presigned_url)
         """
 
     def get_attributes(
@@ -127,14 +124,14 @@ class SimpleDBClient:
         ConsistentRead: bool = None,
     ) -> GetAttributesResultTypeDef:
         """
-        [Client.get_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.get_attributes)
+        [Client.get_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.get_attributes)
         """
 
     def list_domains(
         self, MaxNumberOfDomains: int = None, NextToken: str = None
     ) -> ListDomainsResultTypeDef:
         """
-        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.list_domains)
+        [Client.list_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.list_domains)
         """
 
     def put_attributes(
@@ -145,24 +142,24 @@ class SimpleDBClient:
         Expected: UpdateConditionTypeDef = None,
     ) -> None:
         """
-        [Client.put_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.put_attributes)
+        [Client.put_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.put_attributes)
         """
 
     def select(
         self, SelectExpression: str, NextToken: str = None, ConsistentRead: bool = None
     ) -> SelectResultTypeDef:
         """
-        [Client.select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Client.select)
+        [Client.select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Client.select)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
+        [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["select"]) -> SelectPaginator:
         """
-        [Paginator.Select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Paginator.Select)
+        [Paginator.Select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Paginator.Select)
         """
