@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_sdb import SimpleDBClient
-    from mypy_boto3_sdb import (
+    from mypy_boto3_sdb.paginator import (
         ListDomainsPaginator,
         SelectPaginator,
     )
@@ -33,20 +33,20 @@ __all__ = ("ListDomainsPaginator", "SelectPaginator")
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
+    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Paginator.ListDomains)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDomainsResultTypeDef]:
         """
-        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Paginator.ListDomains.paginate)
+        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Paginator.ListDomains.paginate)
         """
 
 
 class SelectPaginator(Boto3Paginator):
     """
-    [Paginator.Select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Paginator.Select)
+    [Paginator.Select documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Paginator.Select)
     """
 
     def paginate(
@@ -56,5 +56,5 @@ class SelectPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[SelectResultTypeDef]:
         """
-        [Select.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/sdb.html#SimpleDB.Paginator.Select.paginate)
+        [Select.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sdb.html#SimpleDB.Paginator.Select.paginate)
         """
